@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -39,8 +39,6 @@ class LIEF_LOCAL enum_ : public nanobind::enum_<Type> {
   NB_INLINE enum_(nanobind::handle scope, const char *name, const Extra &... extra) :
     nanobind::enum_<Type>{scope, name, extra...}
   {
-    constexpr bool is_arithmetic = (std::is_same_v<nanobind::is_arithmetic, Extra> || ...);
-    constexpr bool is_flag = (std::is_same_v<nanobind::is_flag, Extra> || ...);
     def_static("from_value", [] (Underlying i) -> Type {
       nb::object out = nb::cast(static_cast<Type>(i));
       if (nb::isinstance<nb::int_>(out)) {
