@@ -10,6 +10,8 @@
 //! }
 //! ```
 
+use std::path::Path;
+
 pub mod binary;
 pub mod builder;
 pub mod dynamic;
@@ -21,6 +23,7 @@ pub mod section;
 pub mod segment;
 pub mod symbol;
 pub mod symbol_versioning;
+pub mod parser_config;
 
 #[doc(inline)]
 pub use binary::Binary;
@@ -58,7 +61,15 @@ pub use symbol_versioning::{
     SymbolVersionRequirement,
 };
 
+#[doc(inline)]
+pub use parser_config::Config as ParserConfig;
+
 /// Parse an ELF file from the given file path
-pub fn parse(path: &str) -> Option<Binary> {
+pub fn parse<P: AsRef<Path>>(path: P) -> Option<Binary> {
     Binary::parse(path)
 }
+
+/// Parse an ELF file from the given file path and configuration
+pub fn parse_with_config<P: AsRef<Path>>(path: P, config: &ParserConfig) -> Option<Binary> {
+    Binary::parse_with_config(path, config)
+}
