@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,9 +16,11 @@
 #include "LIEF/Abstract/Binary.hpp"
 
 #include "LIEF/Visitor.hpp"
+#include "LIEF/config.h"
 
 #include "logging.hpp"
 #include "frozen.hpp"
+#include "paging.hpp"
 
 #include "LIEF/Abstract/Section.hpp"
 #include "LIEF/Abstract/Symbol.hpp"
@@ -50,10 +52,15 @@ const Symbol* Binary::get_symbol(const std::string& name) const {
   return *it_symbol;
 }
 
-
-result<uint64_t> Binary::get_function_address(const std::string&) const {
-  LIEF_ERR("Not implemented for this format");
-  return make_error_code(lief_errors::not_implemented);
+result<uint64_t> Binary::get_function_address(const std::string& name) const {
+  if constexpr (lief_extended) {
+    if (const DebugInfo* dbg = debug_info()) {
+      if (auto addr = dbg->find_function_address(name)) {
+        return *addr;
+      }
+    }
+  }
+  return make_error_code(lief_errors::not_found);
 }
 
 std::vector<uint64_t> Binary::xref(uint64_t address) const {
@@ -69,6 +76,11 @@ std::vector<uint64_t> Binary::xref(uint64_t address) const {
   return result;
 }
 
+uint64_t Binary::page_size() const {
+  return get_pagesize(*this);
+}
+
+
 void Binary::accept(Visitor& visitor) const {
   visitor.visit(*this);
 }
