@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2023 R. Thomas
- * Copyright 2017 - 2023 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_PE_USER32_DLL_LOOKUP_H_
-#define LIEF_PE_USER32_DLL_LOOKUP_H_
-
+#ifndef LIEF_PE_USER32_DLL_LOOKUP_H
+#define LIEF_PE_USER32_DLL_LOOKUP_H
+#include <cstdint>
 
 namespace LIEF {
 namespace PE {
 
-const char* user32_dll_lookup(uint32_t i) {
+inline const char* user32_dll_lookup(uint32_t i) {
   switch(i) {
   case 0x0001: return "ActivateKeyboardLayout";
   case 0x0002: return "AdjustWindowRect";
