@@ -5,6 +5,6 @@ from utils import get_sample
 
 def test_core_offset_0():
     file = get_sample('ELF/ELF_Core_issue_808.core')
-    core = lief.parse(file)
+    core = lief.ELF.parse(file)
     assert len(core.notes) == 7
 
